diff -r cbd3ea351e31 src/platform/StdFile.cpp
--- a/src/platform/StdFile.cpp	Mon Mar 29 01:58:02 2010 +0200
+++ b/src/platform/StdFile.cpp	Mon Mar 29 20:46:23 2010 +0200
@@ -5,6 +5,7 @@
  * Copyright (c) 2002-2003, 2006-2008  Sven Eberhardt
  * Copyright (c) 2002, 2004-2005, 2008  Peter Wortmann
  * Copyright (c) 2004-2006, 2008  Günther Brammer
+ * Copyright (c) 2010  Carl-Philip Hnsch
  * Copyright (c) 2001-2009, RedWolf Design GmbH, http://www.clonk.de
  *
  * Portions might be copyrighted by other authors who have contributed
@@ -52,6 +53,14 @@
 static const char *DirectorySeparators = "/";
 #endif
 
+bool FileIsOnBlacklist(const char* filename) //The file Blacklist function to ignore temp files
+{
+	if (filename[0]=='.') return true; //ignore the std folders ".", ".." and all ".*" files
+	if(filename[strlen(filename)-1]=='~') return true; //ignore all tmp files
+	return false;
+}
+
+
 // Return pointer to position after last backslash.
 
 char *GetFilename(char *szPath)
@@ -444,6 +453,7 @@
 
 bool FileExists(const char *szFilename)
 {
+	if (FileIsOnBlacklist(szFilename)) return false;
 	return (!access(szFilename,F_OK));
 }
 
@@ -635,6 +645,7 @@
 
 bool DirectoryExists(const char *szFilename)
 {
+	if (FileIsOnBlacklist(szFilename)) return false;
 	// Ignore trailing slash or backslash, except when we are probing the
 	// root directory '/'.
 	char bufFilename[_MAX_PATH + 1];
@@ -668,9 +679,7 @@
 	if (!szSource || !szTarget) return false;
 	if (!DirectoryExists(szSource)) return false;
 	// Do not process system navigation directories
-	if (SEqual(GetFilename(szSource),".")
-	    || SEqual(GetFilename(szSource),".."))
-		return true;
+	if (FileIsOnBlacklist(GetFilename(szSource))) return true;
 	// Overwrite target
 	//if (ItemExists(szTarget))
 	if (!EraseItem(szTarget)) return false;
@@ -714,8 +723,7 @@
 bool EraseDirectory(const char *szDirName)
 {
 	// Do not process system navigation directories
-	if (SEqual(GetFilename(szDirName),".")
-	    || SEqual(GetFilename(szDirName),".."))
+	if (SEqual(szDirName, "..") || SEqual(szDirName, "."))
 		return true;
 	char path[_MAX_PATH+1];
 #ifdef _WIN32
@@ -904,7 +912,7 @@
 	do
 	{
 		// ...unless they're . or ..
-		if (file.cFileName[0] == '.' && (file.cFileName[1] == '\0' || (file.cFileName[1] == '.' && file.cFileName[2] == '\0')))
+		if (FileIsOnBlacklist(file.cFileName))
 			continue;
 		p->files.push_back(file.cFileName);
 	}
@@ -982,7 +990,7 @@
 		return 0;
 	do
 	{
-		if (SEqual(fdt.name, ".") || SEqual(fdt.name, "..")) continue;
+		if ((FileIsOnBlacklist(fdt.name))) continue;
 		SCopy(fdt.name,GetFilename(szFilename));
 		if ((*fnCallback)(szFilename))
 			iFileCount++;
